@@ -11,12 +11,13 @@ T = TypeVar("T", bound="IncidentRoleAssignmentPayloadRequestBody")
 class IncidentRoleAssignmentPayloadRequestBody:
     """
     Example:
-        {'assignee': {'email': 'Ratione libero qui est atque aut aut.', 'id': 'Ab dolorem consequuntur odio qui.',
-            'slack_user_id': 'Voluptas id.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}
+        {'assignee': {'email': 'Dolore autem ea et voluptatem minus aut.', 'id': 'Ut doloribus porro et sit nihil.',
+            'slack_user_id': 'Alias aut rerum fugiat exercitationem maiores.'}, 'incident_role_id':
+            '01FH5TZRWMNAFB0DZ23FD1TV96'}
 
     Attributes:
-        assignee (UserReferencePayloadRequestBody):  Example: {'email': 'Qui quo deserunt id.', 'id': 'Omnis ut.',
-            'slack_user_id': 'Adipisci commodi omnis consequatur.'}.
+        assignee (UserReferencePayloadRequestBody):  Example: {'email': 'Mollitia fugit consequatur.', 'id': 'Et
+            excepturi enim culpa ut.', 'slack_user_id': 'Eos et et possimus molestiae rem quia.'}.
         incident_role_id (str): Unique ID of an incident role Example: 01FH5TZRWMNAFB0DZ23FD1TV96.
     """
 
