@@ -47,7 +47,10 @@ class IncidentsCreateRequestBody:
     Attributes:
         idempotency_key (str): Unique string used to de-duplicate incident create requests Example: alert-uuid.
         severity_id (str):  Example: Dolorum officia..
-        visibility (IncidentsCreateRequestBodyVisibility): Whether the incident is public or private Example: public.
+        visibility (IncidentsCreateRequestBodyVisibility): Whether the incident should be open to anyone in your Slack
+            workspace (public), or invite-only (private). For more information on Private Incidents see our [help
+            centre](https://help.incident.io/en/articles/5947963-can-we-mark-incidents-as-sensitive-and-restrict-access).
+            Example: public.
         custom_field_entries (Union[Unset, List[CustomFieldEntryPayloadRequestBody]]): Set the incident's custom fields
             to these values Example: [{'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'values': [{'id':
             '01FCNDV6P870EA6S7TK1DSYDG0', 'value_link': 'https://google.com/', 'value_numeric': '123.456',
