@@ -11,15 +11,14 @@ T = TypeVar("T", bound="UserReferencePayloadRequestBody")
 class UserReferencePayloadRequestBody:
     """
     Example:
-        {'email': 'Voluptas excepturi eius tempora sapiente id.', 'id': 'Quo eveniet molestias.', 'slack_user_id': 'Aut
-            quis repellat a delectus et deserunt.'}
+        {'email': 'Mollitia fugit consequatur.', 'id': 'Et excepturi enim culpa ut.', 'slack_user_id': 'Eos et et
+            possimus molestiae rem quia.'}
 
     Attributes:
-        email (Union[Unset, str]): The user's email address, matching the email on their Slack account Example: Quo
-            deserunt id quam adipisci..
-        id (Union[Unset, str]): The incident.io ID of a user Example: A voluptatem et omnis ut distinctio..
-        slack_user_id (Union[Unset, str]): The ID of the user's Slack account. Example: Omnis consequatur consequatur et
-            ut..
+        email (Union[Unset, str]): The user's email address, matching the email on their Slack account Example: Magnam
+            earum dolorem dicta inventore qui vitae..
+        id (Union[Unset, str]): The incident.io ID of a user Example: Harum ut quos repudiandae nesciunt..
+        slack_user_id (Union[Unset, str]): The ID of the user's Slack account. Example: Accusantium iure quisquam id..
     """
 
     email: Union[Unset, str] = UNSET
